@@ -54,10 +54,12 @@ class Gyoto::Astrobj::FixedStar : public Astrobj::UniformSphere {
  protected:
   
   double pos_[3];///< x, y, z or r, theta, phi
-  
+  bool rotating_; ///< Whether the blob is rotating at Metric::circularVelocity()
+
   // Constructors - Destructor
   // -------------------------
  public:
+  GYOTO_OBJECT;
   
   /**
    * Everything is undefined, call setCoordSys(), setPos() and
@@ -79,6 +81,15 @@ class Gyoto::Astrobj::FixedStar : public Astrobj::UniformSphere {
  public:
   double const * getPos() const; ///< Get const pointer to pos_
   void getPos(double* dst) const; ///< Get a copy of the pos_ array
+
+  std::vector<double> position() const; ///< Get vector copy of #pos_
+  void position(std::vector<double> const&); ///< Set #pos_ from vector
+
+  double rMax();
+
+  bool rotating() const ;
+  void rotating(bool) ;
+
   using Generic::metric;
   virtual void metric(SmartPointer<Metric::Generic> metric) ;
   using UniformSphere::radius;
@@ -86,15 +97,6 @@ class Gyoto::Astrobj::FixedStar : public Astrobj::UniformSphere {
   void setPos(const double[3]); ///< Set pos_ array
   //  void setCoordSys(int); ///< set coordinate system
   
-  virtual int setParameter(std::string name,
-			   std::string content,
-			   std::string unit);
-
- public:
-#ifdef GYOTO_USE_XERCES
-  virtual void fillElement(FactoryMessenger *fmp) const ;
-#endif
-
   // Outputs
   // -------
  protected:
