@@ -17,7 +17,7 @@
  */
 
 /*
-    Copyright 2011 Thibaut Paumard
+    Copyright 2011-2014, 2016 Thibaut Paumard
 
     This file is part of Gyoto.
 
@@ -54,6 +54,8 @@ namespace Gyoto {
 #include <stddef.h>
 #include <iostream>
 #include <typeinfo>
+#include <string>
+#include <vector>
 
 /**
  * \brief Can be pointed to by a SmartPointer
@@ -96,7 +98,7 @@ class Gyoto::SmartPointee
   int getRefCount () ;  ///< Get the current number of references
   /**
    * Various classes need to provide a subcontractor to be able to
-   * instanciate themselves upon order from the Factory. A
+   * instantiate themselves upon order from the Factory. A
    * subcontractor is a function (often a static member function)
    * which accepts a pointer to a FactoryMessenger as unique
    * parameter, communicates with the Factory using this messenger to
@@ -109,7 +111,7 @@ class Gyoto::SmartPointee
    * Metric::Register(), Spectrum::Register().
    */
   typedef Gyoto::SmartPointer<Gyoto::SmartPointee>
-    Subcontractor_t(Gyoto::FactoryMessenger*);
+    Subcontractor_t(Gyoto::FactoryMessenger*, std::vector<std::string> const &);
   ///< A subcontractor builds an object upon order from the Factory
 
 };
