@@ -4,7 +4,7 @@
  */
 
 /*
-    Copyright 2011-2015 Frederic Vincent, Thibaut Paumard
+    Copyright 2011-2016 Frederic Vincent, Thibaut Paumard
 
     This file is part of Gyoto.
 
@@ -55,19 +55,31 @@ namespace Gyoto {
  * Worldline.
  */
 #define GYOTO_WORLDLINE_PROPERTIES(c)					\
-  GYOTO_PROPERTY_BOOL(c, HighOrderImages, PrimaryOnly, _secondary)	\
-  GYOTO_PROPERTY_DOUBLE(c, RelTol, _relTol)				\
-  GYOTO_PROPERTY_DOUBLE(c, AbsTol, _absTol)				\
-  GYOTO_PROPERTY_DOUBLE(c, DeltaMaxOverR, _deltaMaxOverR)		\
-  GYOTO_PROPERTY_DOUBLE(c, DeltaMax, _deltaMax)				\
-  GYOTO_PROPERTY_DOUBLE(c, DeltaMin, _deltaMin)				\
-  GYOTO_PROPERTY_STRING(c, Integrator, _integrator)			\
-  GYOTO_PROPERTY_SIZE_T(c, MaxIter, _maxiter)				\
-  GYOTO_PROPERTY_BOOL(c, Adaptive, NonAdaptive, _adaptive)		\
-  GYOTO_PROPERTY_DOUBLE_UNIT(c, MinimumTime, _tMin)			\
-  GYOTO_PROPERTY_DOUBLE_UNIT(c, Delta, _delta)				\
-  GYOTO_PROPERTY_VECTOR_DOUBLE(c, InitCoord, _initCoord)		\
-  GYOTO_PROPERTY_METRIC(c, Metric, _metric)
+  Gyoto::Property("Gyoto::Worldline", "Time-like or null geodesic."),	\
+    GYOTO_PROPERTY_BOOL(c, HighOrderImages, PrimaryOnly, _secondary,	\
+			"Whether to stop Photon integration at 180° deflection.") \
+    GYOTO_PROPERTY_DOUBLE(c, RelTol, _relTol,				\
+			  "Relative tolerance for the adaptive step integrators.") \
+    GYOTO_PROPERTY_DOUBLE(c, AbsTol, _absTol,				\
+			  "Absolute tolerance for the adaptive step integrators.") \
+    GYOTO_PROPERTY_DOUBLE(c, DeltaMaxOverR, _deltaMaxOverR,		\
+			  "Maximum value of step/distance from center of mass.") \
+    GYOTO_PROPERTY_DOUBLE(c, DeltaMax, _deltaMax, "Maximum step (geometrical units).")	\
+    GYOTO_PROPERTY_DOUBLE(c, DeltaMin, _deltaMin, "Minimum step (geometrical units).")	\
+    GYOTO_PROPERTY_STRING(c, Integrator, _integrator,			\
+			  "Name of integrator (\"runge_kutta_fehlberg78\").")			\
+    GYOTO_PROPERTY_SIZE_T(c, MaxIter, _maxiter,				\
+			  "Maximum number of integration steps.")	\
+    GYOTO_PROPERTY_BOOL(c, Adaptive, NonAdaptive, _adaptive,		\
+			"Whether to use an adaptive step.")		\
+    GYOTO_PROPERTY_DOUBLE_UNIT(c, MinimumTime, _tMin,			\
+			       "Do not integrate earlier than this date (geometrical_time).") \
+    GYOTO_PROPERTY_DOUBLE_UNIT(c, Delta, _delta,			\
+			       "Initial integration step (geometrical units).")		\
+    GYOTO_PROPERTY_VECTOR_DOUBLE(c, InitCoord, _initCoord,		\
+				 "Initial 8-coordinate.")		\
+    GYOTO_PROPERTY_METRIC(c, Metric, _metric,				\
+			  "The geometry of space-time at this end of the Universe.")
 
 /// Define the wrapper accessors used in GYOTO_WORLDLINE_PROPERTIES(class)
 /**
@@ -184,7 +196,7 @@ namespace Gyoto {
  * extended as needed using xExpand(). These coordinates can be
  * retrieved using get_t(), get_xyz(), getCartesian(), getCoord() etc.
  *
- * Worldline does not derive from Object, and does not instanciate a
+ * Worldline does not derive from Object, and does not instantiate a
  * Property list. This is because this would lead to multiple
  * inheritance of the Object base in derived classes. Instead,
  * #GyotoWorldline.h provides a few macros that can be used to include
@@ -319,7 +331,7 @@ class Gyoto::Worldline
   
   /// Refine constructor
   /**
-   * Meant to instanciate a copy of orig with a smaller step to refine
+   * Meant to instantiate a copy of orig with a smaller step to refine
    * integration, for instance for more accurate radiative transfer
    * integration.
    *
@@ -346,7 +358,25 @@ class Gyoto::Worldline
   void initCoord(std::vector<double> const&); 
   std::vector<double> initCoord() const; 
 
-  virtual void   setInitCoord(const double coord[8], int dir = 0); ///< Set Initial coordinate
+  /**
+   * \brief Set Initial coordinate
+   *
+   * Set #imin_=#imax_=#i0_, and x<i>_[i0_]=coord[<i>].
+   *
+   * If dir==1, #i0_ is set to 0. If dir==-1, #i0_ is set to #x_size_-1.
+   *
+   * If dir==0 and the Worldine has never been computed (#i0_==0,
+   * #imin_==1 and #imax_==0), then dir defaults to 1 for a massive
+   * particle and -1 for a massless particle.
+   *
+   * If dir==0 and the Worldine has already been computed, #i0_ is not
+   * changed.
+   *
+   * \param coord new initial coordinates
+   * \param dir direction of integration. 1 for forward integration,
+   *        -1 for backards integration, 0 for unknown or both.
+   */
+  virtual void   setInitCoord(const double coord[8], int dir = 0);
 
   /**
    * \brief Set initial coordinate
@@ -355,10 +385,10 @@ class Gyoto::Worldline
    * \param vel initial 3-velocity
    * \param dir direction of integration
    */
-  virtual void setInitCoord(double pos[4], double vel[3], int dir=1);
+  virtual void setInitCoord(double const pos[4], double const vel[3], int dir=0);
 
-  virtual void setPosition(double pos[4]); ///< Set initial 4-position
-  virtual void setVelocity(double vel[3]); ///< Set initial 3-velocity
+  virtual void setPosition(double const pos[4]); ///< Set initial 4-position
+  virtual void setVelocity(double const vel[3]); ///< Set initial 3-velocity
 
   void reset() ; ///< Forget integration, keeping initial contition
   void reInit() ; ///< Reset and recompute particle properties
@@ -509,7 +539,7 @@ class Gyoto::Worldline
   void getCartesianPos(size_t index, double dest[4]) const; ///< Get Cartesian expression of 4-position at index.
 
 
-  virtual void xStore(size_t ind, double coord[8]) ; ///< Store coord at index ind
+  virtual void xStore(size_t ind, double const coord[8]) ; ///< Store coord at index ind
   virtual void xFill(double tlim) ; ///< Fill x0, x1... by integrating the Worldline from previously set inittial condition to time tlim
 
 
