@@ -140,15 +140,15 @@ void ygyoto_Spectrometer_generic_eval
     "nullifycoord", "kind", "coordkind", "setparameter", "scalarprod",	\
     "mass", "deltamin", "deltamax", "keplerian",					\
     "unitlength", "circularvelocity",					\
-    "christoffel", "xmlwrite", "clone"
+    "christoffel", "xmlwrite", "clone", "help"
 // Number of those keywords
-#define YGYOTO_METRIC_GENERIC_KW_N 15
+#define YGYOTO_METRIC_GENERIC_KW_N 16
 
 // Keywords processed by ygyoto_Astrobj_generic_eval
 #define YGYOTO_ASTROBJ_GENERIC_KW "metric", "rmax", "opticallythin",	\
-    "xmlwrite", "kind", "setparameter", "clone"
+    "xmlwrite", "kind", "setparameter", "clone", "help"
 // number of those keywords
-#define YGYOTO_ASTROBJ_GENERIC_KW_N 7
+#define YGYOTO_ASTROBJ_GENERIC_KW_N 8
 
 // Keywords processed by ygyoto_ThinDisk_generic_eval
 #define YGYOTO_THINDISK_GENERIC_KW \
@@ -161,15 +161,17 @@ void ygyoto_Spectrometer_generic_eval
 #define YGYOTO_ASTROBJ_BASE_MAX_KW_N YGYOTO_THINDISK_GENERIC_KW_N
 
 // Keywords processed by ygyoto_Spectrum_generic_eval
-#define YGYOTO_SPECTRUM_GENERIC_KW "xmlwrite", "kind", "setparameter", "clone", "integrate"
+#define YGYOTO_SPECTRUM_GENERIC_KW				\
+  "xmlwrite", "kind", "setparameter", "clone", "help", "integrate"
 // number of those keywords
-#define YGYOTO_SPECTRUM_GENERIC_KW_N 5
+#define YGYOTO_SPECTRUM_GENERIC_KW_N 6
 
 // Keywords processed by ygyoto_Spectrometer_generic_eval
-#define YGYOTO_SPECTROMETER_GENERIC_KW "kind", "xmlwrite", "clone", "nsamples",\
+#define YGYOTO_SPECTROMETER_GENERIC_KW			\
+  "kind", "xmlwrite", "clone", "help", "nsamples",		\
     "setparameter", "channels", "midpoints", "widths"
 // number of those keywords
-#define YGYOTO_SPECTROMETER_GENERIC_KW_N 8
+#define YGYOTO_SPECTROMETER_GENERIC_KW_N 9
 
 /*
 
@@ -480,6 +482,14 @@ void ygyoto_Spectrometer_generic_eval
     (*OBJ)-> METHOD ;			\
   }
 
+#define YGYOTO_WORKER_HELP				\
+  if ((iarg=kiargs[++k])>=0) {				\
+    GYOTO_DEBUG << "help" << std::endl ;		\
+    iarg+=*rvset;					\
+    (*OBJ)-> help() ;					\
+    ypush_nil();					\
+  }
+
 #define YGYOTO_WORKER_CALL_GENERIC(BASE) \
   ygyoto_##BASE##_generic_eval(YGYOTO_CAT(OBJ,_), \
 			       kiargs+k+1, piargs, rvset, paUsed, unit);
